@@ -19,7 +19,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "couchdb-glib.h"
+#include <libsoup/soup-method.h>
+#include "couchdb-document.h"
 #include "dbwatch.h"
 #include "utils.h"
 
@@ -31,7 +32,7 @@ process_change (DBWatch *watch, JsonNode *node)
 {
 	JsonObject *this_change;
 	const gchar *id;
-	CouchDBDocument *document;
+	CouchdbDocument *document;
 	GError *error = NULL;
 
 	if (json_node_get_node_type (node) != JSON_NODE_OBJECT)
@@ -79,11 +80,11 @@ watch_timeout_cb (gpointer user_data)
 	DBWatch *watch = (DBWatch *) user_data;
 
 	url = g_strdup_printf ("%s/%s/_changes?since=%d",
-			       watch->couchdb->hostname,
+			       couchdb_session_get_uri (watch->couchdb),
 			       watch->dbname,
 			       watch->last_update_seq);
-	parser = send_message_and_parse (watch->couchdb, SOUP_METHOD_GET, url, NULL, &error);
-	if (parser != NULL) {
+	parser = json_parser_new ();
+	if (couchdb_session_send_message (watch->couchdb, SOUP_METHOD_GET, url, NULL, parser, &error)) {
 		JsonNode *root_node;
 
 		root_node = json_parser_get_root (parser);
@@ -103,17 +104,16 @@ watch_timeout_cb (gpointer user_data)
 
 			if (json_object_has_member (root_object, "last_seq"))
 				watch->last_update_seq = json_object_get_int_member (root_object, "last_seq");
-		}
-
-		g_object_unref (G_OBJECT (parser));
+		}		
 	}
 
 	/* Free memory */
+	g_object_unref (G_OBJECT (parser));
 	g_free (url);
 }
 
 DBWatch *
-dbwatch_new (CouchDB *couchdb, const gchar *dbname, gint update_seq)
+dbwatch_new (CouchdbSession *couchdb, const gchar *dbname, gint update_seq)
 {
 	DBWatch *watch;
 	guint timeout;
@@ -124,7 +124,7 @@ dbwatch_new (CouchDB *couchdb, const gchar *dbname, gint update_seq)
 	watch->last_update_seq = update_seq;
 
 	/* Set timeout to check for changes every 5 minutes*/
-	if (g_str_has_prefix (watch->couchdb->hostname, "http://127.0.0.1"))
+	if (g_str_has_prefix (couchdb_session_get_uri (watch->couchdb), "http://127.0.0.1"))
 		timeout = LOCAL_TIMEOUT_SECONDS;
 	else
 		timeout = REMOTE_TIMEOUT_SECONDS;
